<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Українська [UA]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=523
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = "Українська";
$lang_info['country'] = "Україна";
$lang_info['direction'] = "ltr";
$lang_info['code'] = "ua";
$lang_info['zero_plural'] = "1";

$lang['%d album updated'] = '%d альбом оновлено';
$lang['%d albums updated'] = 'альбомів оновлено: %d';
$lang['%d comment to validate'] = '%d коментар на перевірці';
$lang['%d comments to validate'] = 'коментарів на перевірці: %d';
$lang['%d new comment'] = '%d новий коментар';
$lang['%d new comments'] = 'нових коментарів: %d';
$lang['%d comment'] = '%d коментар';
$lang['%d comments'] = 'коментарів: %d';
$lang['%d hit'] = '%d перегляд';
$lang['%d hits'] = 'переглядів: %d';
$lang['%d new photo'] = '%d нова фотографія';
$lang['%d new photos'] = 'нових фотографій: %d';
$lang['%d new user'] = '%d новий користувач';
$lang['%d new users'] = 'нових користувачів: %d';
$lang['About'] = 'Про програму';
$lang['All tags'] = 'Всі теги';
$lang['Any tag'] = 'Будь-який тег';
$lang['At least one listed rule must be satisfied.'] = 'Хоча б одне правило повинне виконуватись.';
$lang['At least one tag must match'] = 'Хоча б один тег повинен бути присутнім';
$lang['Author'] = 'Автор';
$lang['Albums'] = 'Альбоми';
$lang['Album'] = 'Альбом';
$lang['Close this window'] = 'Закрити це вікно';
$lang['Complete RSS feed (photos, comments)'] = 'Повний RSS канал (фотографії, коментарі)';
$lang['Confirm Password'] = 'Підтвердіть пароль';
$lang['Connection settings'] = "Налаштування з'єднання";
$lang['Login'] = 'Авторизація';
$lang['Contact webmaster'] = 'Техпідтримка';
$lang['Create a new account'] = 'Створити новий аккаунт';
$lang['Created on'] = 'Дата зйомки';
$lang['Creation date'] = 'Дата зйомки';
$lang['Current password is wrong'] = 'Введений невірний пароль';
$lang['Dimensions'] = 'Розміри';
$lang['Display'] = 'Порядок';
$lang['Each listed rule must be satisfied.'] = 'Усі перераховані правила повинні виконуватись.';
$lang['Email address'] = 'Адреса електронної пошти';
$lang['Enter your personnal informations'] = 'Вкажіть вашу персональну інформацію';
$lang['Error sending email'] = 'Помилка відправки електронної пошти';
$lang['File name'] = "Ім'я файлу";
$lang['File'] = 'Файл';
$lang['Filesize'] = 'Розмір файлу';
$lang['Filter and display'] = 'Відфільтрувати і показати';
$lang['Filter'] = 'Фільтр';
$lang['Forgot your password?'] = 'Забули пароль?';
$lang['Go through the gallery as a visitor'] = 'Увійти в галерею як відвідувач';
$lang['Help'] = 'Допомога';
$lang['Identification'] = 'Ідентифікація';
$lang['Photos only RSS feed'] = 'RSS канал тільки з фотографіями';
$lang['Keyword'] = 'Ключеве слово';
$lang['day'][0] = "Неділя";
$lang['day'][1] = "Понеділок";
$lang['day'][2] = "Вівторок";
$lang['day'][3] = "Середа";
$lang['day'][4] = "Четвер";
$lang['day'][5] = "П'ятниця";
$lang['day'][6] = "Субота";
$lang['month'][10] = "Жовтень";
$lang['month'][11] = "Листопад";
$lang['month'][12] = "Грудень";
$lang['month'][1] = "Січень";
$lang['month'][2] = "Лютий";
$lang['month'][3] = "Березень";
$lang['month'][4] = "Квітень";
$lang['month'][5] = "Травень";
$lang['month'][6] = "Червень";
$lang['month'][7] = "Липень";
$lang['month'][8] = "Серпень";
$lang['month'][9] = "Вересень";
$lang['New password confirmation does not correspond'] = 'Підтвердження нового пароля не співпадає';
$lang['Notification'] = 'Повідомлення';
$lang['Number of items'] = 'Кількість елементів';
$lang['Original dimensions'] = 'Оригінальні розміри';
$lang['Password forgotten'] = 'Забули пароль';
$lang['Password'] = 'Пароль';
$lang['Post date'] = 'Дата розміщення';
$lang['Posted on'] = 'Опубліковано';
$lang['Profile'] = 'Профіль';
$lang['Quick connect'] = "Швидке з'єднання";
$lang['RSS feed'] = 'RSS канал';
$lang['Register'] = 'Реєстрація';
$lang['Registration'] = 'Реєстрація';
$lang['Related tags'] = "Пов'язані теги";
$lang['Reset'] = 'Скинути';
$lang['Retrieve password'] = 'Відновити пароль';
$lang['Search rules'] = 'Критерії пошуку';
$lang['Search tags'] = 'Теги пошуку';
$lang['Search'] = 'Пошук';
$lang['display available tags'] = 'відображати доступні теги';
$lang['Since'] = 'З';
$lang['Sort by'] = 'Сортувати за';
$lang['Sort order'] = 'Порядок сортування';
$lang['Tag'] = 'Тег';
$lang['Tags'] = 'Теги';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'RSS канал надсилає повідомлення про нові події з цього сайту: нові фотографії, оновлені альбоми, нові коментарі. Використовуйте читання RSS каналів.';
$lang['Unknown feed identifier'] = 'Невідомий ідентифікатор каналу';
$lang['User comments'] = 'Коментарі користувача';
$lang['Username'] = "Ім'я користувача";
$lang['Visits'] = 'Відвідувань';
$lang['Webmaster'] = 'Вебмайстер';
$lang['Week %d'] = 'Тиждень %d';
$lang['About Piwigo'] = 'Про Piwigo';
$lang['You are not authorized to access the requested page'] = 'Ви не авторизовані для доступу до запитуваної сторінки';
$lang['add to caddie'] = 'додати в кадді';
$lang['add this photo to your favorites'] = 'Додати це фото в обране';
$lang['Administration'] = 'Адміністрування';
$lang['all'] = 'всі';
$lang['ascending'] = 'в порядку зростання';
$lang['useful when password forgotten'] = "корисно, коли забули пароль";
$lang['Quick search'] = "Швидкий пошук";
$lang['Connected user: %s'] = "Підключений користувач: %s";
$lang['Browser: %s'] = "Браузер: %s";
$lang['Author: %s'] = "Автор: %s";
$lang['Comment: %s'] = "Коментар: %s";
$lang['Comment by %s'] = "Коментар %s";
$lang['User: %s'] = "Користувач: %s";
$lang['Email: %s'] = "Електронна пошта: %s";
$lang['Admin: %s'] = "Адміністратор: %s";
$lang['Registration of %s'] = "Зареєстровано %s";
$lang['Tag results for'] = "Результати для";
$lang['from %s to %s'] = "від %s до %s";
$lang['Play of slideshow'] = "Показувати слайдшоу";
$lang['Pause of slideshow'] = "Пауза слайдшоу";
$lang['Repeat the slideshow'] = "Повторити слайдшоу";
$lang['Not repeat the slideshow'] = "Не повторювати слайдшоу";
$lang['Reduce diaporama speed'] = "Зменшити швидкість слайдшоу";
$lang['Accelerate diaporama speed'] = "Збільшити швидкість слайдшоу";
$lang['Submit'] = "Відправити";
$lang['Yes'] = "Так";
$lang['No'] = "Ні";
$lang['Piwigo Help'] = "Допомога Piwigo";
$lang['Rank'] = "Ранг";
$lang['group by letters'] = "групувати по буквах";
$lang['letters'] = "букви";
$lang['show tag cloud'] = "показувати хмару тегів";
$lang['cloud'] = "хмара";
$lang['Reset to default values'] = "Скинути на значення за замовчуванням";
$lang['Sent by'] = "Надіслано";
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = "Куки заблоковані або не підтримуються вашим браузером. Ви повинні увімкнути куки, щоб увійти.";
$lang['author(s) : %s'] = 'автор(и) : %s';
$lang['Expand all albums'] = 'Розгорнути всі альбоми';
$lang['posted after %s (%s)'] = 'додано після %s (%s)';
$lang['posted before %s (%s)'] = 'додано до %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'додано між %s (%s) і %s (%s)';
$lang['posted on %s'] = 'додано в %s';
$lang['Best rated'] = 'Найбільший рейтинг';
$lang['display best rated photos'] = 'показати фотографії з найбільшим рейтингом';
$lang['caddie'] = 'Кадді';
$lang['Calendar'] = 'Календар';
$lang['All'] = 'Всі';
$lang['display each day with photos, month per month'] = 'показувати кожен день з фотографіями, місяць за місяцем';
$lang['View'] = 'Перегляд';
$lang['chronology_monthly_calendar'] = 'Місячний календар';
$lang['chronology_monthly_list'] = 'Список місяців';
$lang['chronology_weekly_list'] = 'Список тижнів';
$lang['Click here if your browser does not automatically forward you'] = 'Натисніть тут, якщо ваш браузер не перенаправив вас автоматично';
$lang['comment date'] = 'дата коментаря';
$lang['Comment'] = 'Коментар';
$lang['Your comment has been registered'] = 'Ваш коментар був зареєстрований';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Анти-флуд система : будь ласка, зачекайте кілька секунд перед тим, як додати новий коментар';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Ваш коментар НЕ був зареєстрований, оскільки він не відповідає вимогам';
$lang['An administrator must authorize your comment before it is visible.'] = 'Адміністратор повинен авторизувати ваш коментар перед тим, як він стане видимим.';
$lang['This login is already used by another user'] = 'Цей логін вже використовується іншим користувачем';
$lang['Comments'] = 'Коментарі';
$lang['Add a comment'] = 'Додати коментар';
$lang['created after %s (%s)'] = 'створено після %s (%s)';
$lang['created before %s (%s)'] = 'створено до %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'створено між %s (%s) і %s (%s)';
$lang['created on %s'] = 'створено в %s';
$lang['Customize'] = 'Налаштування';
$lang['Your Gallery Customization'] = 'Налаштування вашої галереї';
$lang['Default'] = 'За замовчуванням';
$lang['delete this photo from your favorites'] = 'видалити цю фотографію з вибраних';
$lang['Delete'] = 'Видалити';
$lang['descending'] = 'в порядку спадання';
$lang['download'] = 'завантажити';
$lang['download this file'] = 'завантажити цей файл';
$lang['edit'] = 'редагувати';
$lang['wrong date'] = 'невірна дата';
$lang['excluded'] = 'вилучено';
$lang['Your favorites'] = 'Ваші вибрані';
$lang['display your favorites photos'] = 'показати ваші вибрані фотографії';
$lang['Favorites'] = 'Вибрані';
$lang['First'] = 'Початок';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Галерея закрита для обслуговування. Будь ласка, зайдіть пізніше.';
$lang['Page generated in'] = 'Сторінка згенерована за';
$lang['guest'] = 'гість';
$lang['Hello'] = 'Привіт';
$lang['available for administrators only'] = 'доступно тільки для адміністраторів';
$lang['display this album'] = 'показати цей альбом';
$lang['display last user comments'] = 'показати останні коментарі користувачів';
$lang['customize the appareance of the gallery'] = 'налаштувати зовнішній вигляд галереї';
$lang['search'] = 'пошук';
$lang['Home'] = 'Додому';
$lang['in this album'] = 'в цьому альбомі';
$lang['in %d sub-album'] = 'в %d під-альбомі';
$lang['in %d sub-albums'] = 'в %d під-альбомах';
$lang['included'] = 'включено';
$lang['Invalid password!'] = 'Невірний пароль!';
$lang['Language'] = 'Мова';
$lang['last %d days'] = 'останні %d днв';
$lang['Last'] = 'Кінець';
$lang['Logout'] = 'Вийти';
$lang['E-mail address'] = 'E-mail адреса';
$lang['Links'] = 'Ссилки';
$lang['New on %s'] = 'Нове на %s';
$lang['obligatory'] = "обов'язкове";
$lang['Maximum photo height'] = 'Максимальна висота фотографії';
$lang['Maximum height must be a number superior to 50'] = 'Максимальна висота має бути числом, більшим ніж 50';
$lang['Maximum photo width'] = 'Максимальна ширина фотографії';
$lang['Maximum width must be a number superior to 50'] = 'Максимальна ширина повинна бути числом, більшим ніж 50';
$lang['display a calendar by creation date'] = 'показувати календар за датою створення';
$lang['display all photos in all sub-albums'] = 'показувати всі фотографії в усіх під-альбомах';
$lang['return to normal view mode'] = 'повернутися до звичайного режиму перегляду';
$lang['display a calendar by posted date'] = 'показувати календар за датою відправлення';
$lang['Most visited'] = 'Найбільш відвідувані';
$lang['display most visited photos'] = 'показувати найбільш відвідувані фотографії';
$lang['The number of photos per page must be a not null scalar'] = 'Кількість фотографій на сторінці повинно бути цілим ненульовим числом';
$lang['Number of photos per page'] = 'Кількість фотографій на сторінці';
$lang['Unknown identifier'] = 'Невідомий ідентифікатор';
$lang['New password'] = 'Новий пароль';
$lang['Rate this photo'] = 'Оцінити це фото';
$lang['Next'] = 'Наступне';
$lang['no rate'] = 'не оцінено';
$lang['Photos posted within the last %d day.'] = 'Фотографії, розміщені лише протягом останнього %d дня.';
$lang['Photos posted within the last %d days.'] = 'Фотографії, розміщені лише протягом останніх %d днів.';
$lang['password updated'] = 'пароль оновлено';
$lang['Recent period must be a positive integer value'] = "Останній період повинен бути невід'ємним цілим значенням";
$lang['photo'] = 'фото';
$lang['Click on the photo to see it in high definition'] = 'Натисніть на фото, щоб побачити його у високій якості';
$lang['Show file metadata'] = 'Показати метадані';
$lang['Powered by'] = 'Підтримка';
$lang['Preferences'] = 'Налаштування';
$lang['Previous'] = 'Попереднє';
$lang['Random photos'] = 'Випадкові фото';
$lang['display a set of random photos'] = 'показувати випадкові фотографії';
$lang['Recent albums'] = 'Останні альбоми';
$lang['display recently updated albums'] = 'показувати нещодавно оновлені альбоми';
$lang['Recent period'] = 'Останній період';
$lang['Recent photos'] = 'Останні фотографії';
$lang['display most recent photos'] = 'показувати останні фотографії';
$lang['Redirection...'] = 'Перенаправлення...';
$lang['Please, enter a login'] = 'Будь ласка, введіть логін';
$lang['login mustn\'t end with a space character'] = 'логін не повинен закінчуватися на пробіл';
$lang['login mustn\'t start with a space character'] = 'логін не повинен починатися з пробілу';
$lang['this login is already used'] = 'цей логін вже використовується';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'адреса електронної пошти повинна бути у вигляді xxx@yyy.eee (наприклад : jack@altern.org)';
$lang['please enter your password again'] = 'будь ласка, введіть свій пароль ще раз';
$lang['Auto login'] = 'Автологін';
$lang['remove this tag from the list'] = 'видалити цей тег зі списку';
$lang['representative'] = 'зразок';
$lang['Search for Author'] = 'Пошук по автору';
$lang['Search in albums'] = 'Пошук в альбомах';
$lang['Search by Date'] = 'Пошук по даті';
$lang['Date'] = 'Дата';
$lang['End-Date'] = 'Кінцева дата';
$lang['Kind of date'] = 'Вид дати';
$lang['Search for words'] = 'Пошук по словам';
$lang['Search for all terms'] = 'Пошук по всім словам';
$lang['Search for any terms'] = 'Пошук по будь-якому слову';
$lang['Empty query. No criteria has been entered.'] = 'Порожній запит. Не був введений жоден критерій.';
$lang['Search Options'] = 'Опції пошуку';
$lang['%d Kb'] = '%d Кб';
$lang['Search results'] = 'Результати пошуку';
$lang['Search in sub-albums'] = 'Пошук в під-альбомах';
$lang['searched words : %s'] = 'знайдено слів : %s';
$lang['Contact'] = 'Контакт';
$lang['set as album representative'] = 'встановити як обкладинку альбому';
$lang['Show number of comments'] = 'Показувати число коментарів';
$lang['Show number of hits'] = 'Показувати число посилань';
$lang['slideshow'] = 'слайдшоу';
$lang['stop the slideshow'] = 'зупинити слайдшоу';
$lang['Specials'] = 'Спеціальні';
$lang['SQL queries in'] = 'SQL запитів за';
$lang['display only recently posted photos'] = 'показувати тільки нещодавно завантажені фотографії';
$lang['return to the display of all photos'] = 'повернутися до всіх фотографій';
$lang['the beginning'] = 'початок';
$lang['Interface theme'] = 'Тема інтерфейсу';
$lang['Thumbnails'] = 'Ескізи';
$lang['Menu'] = 'Меню';
$lang['A comment on your site'] = 'Коментар на вашому сайті';
$lang['today'] = 'сьогодні';
$lang['Update your rating'] = 'Оновити вай рейтинг';
$lang['wrong filename'] = "невірне ім'я файлу";
$lang['the username must be given'] = "необхідно ім'я користувача";
$lang['Album: %s'] = 'Альбом: %s';
$lang['this email address is already in use'] = 'ця адреса електронної пошти вже використовується';
$lang['Album results for'] = 'Результати для';
$lang['%d photo'] = '%d фотографія';
$lang['%d photos'] = '%d фотографій';
$lang['%d photo is also linked to current tags'] = "%d фотографія також пов'язана з поточними мітками";
$lang['%d photos are also linked to current tags'] = "%d фотографій також пов'язані з поточними мітками";
$lang['display photos linked to this tag'] = "показувати фотографії, пов'язані з поточними мітками";
$lang['photos posted during the last %d days'] = 'фотографії, завантажені протягом останніх %d днів';
$lang['delete all photos from your favorites'] = 'видалити всі фотографії з обраних';
$lang['edit this comment'] = 'редагувати цей коментар';
$lang['Edit a comment'] = 'Редагувати коментар';
$lang['Are you sure?'] = 'Ви впевнені?';
$lang['(!) This comment requires validation'] = '(!) Цей коментар вимагає валідації';
$lang['Welcome'] = 'Ласкаво просимо';
$lang['Welcome to your Piwigo photo gallery!'] = 'Ласкаво просимо до вашої фото-галереї Piwigo!';
$lang['... or browse your empty gallery'] = '... або відкрити вашу порожню галерею';
$lang['... or please deactivate this message, I will find my way by myself'] = '... або, будь ласка, деактивуйте це повідомлення, я знайду рішення сам';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Привіт %s, ваша Piwigo фото-галерея порожня!';
$lang['I want to add photos'] = 'Я хочу додати фотографії';
$lang['Manage this user comment: %s'] = 'Виправити цей коментар користувача: %s';
$lang['Email address is missing. Please specify an email address.'] = 'Відсутня адреса електронної пошти. Будь ласка, вкажіть адресу електронної пошти.';
$lang['This author modified following comment:'] = 'Цей автор змінив наступний коментар:';
$lang['This author removed the comment with id %d'] = 'Цей автор видалив коментар з ідентифікатором %d';
$lang['delete this comment'] = 'видалити цей коментар';
$lang['validate this comment'] = 'перевірити цей коментар';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = "Невірний статус для користувача \"гість\", буде використовуватись статус за замовчуванням. Будь ласка, повідомте вебмайстра.";
$lang['N/A'] = 'невідомий';
$lang['IP: %s'] = "IP: %s";
$lang['html tags are not allowed in login'] = 'логін не повинен містити html тегів';
$lang['%d rates'] = '%d голосів';
$lang['Rating score'] = 'Рейтинговий бал';
$lang['Enter a username or email address'] = 'Введіть ім\'я користувача або адресу електронної пошти';
$lang['Invalid username or email'] = 'Невірне ім\'я користувача або адреса електронної пошти';
$lang['Password reset is not allowed for this user'] = 'Оновлення паролю не дозволено для цього користувача';
$lang['User "%s" has no email address, password reset is not possible'] = 'Користувач "%s" не має адреси електронної пошти, оновлення паролю неможливе';
$lang['Someone requested that the password be reset for the following user account:'] = 'Хтось запросив оновлення паролю для наступного облікового запису користувача:';
$lang['Username "%s" on gallery %s'] = 'Ім\'я "%s" в галереї %s';
$lang['To reset your password, visit the following address:'] = 'Щоб оновити пароль, відвідайте наступну адресу:';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Якщо це було помилкою, просто проігноруйте це повідомлення і нічого не трапиться.';
$lang['Password Reset'] = 'Оновлення паролю';
$lang['Check your email for the confirmation link'] = 'Перевірте вашу пошту на наявність лінку підтвердження';
$lang['Invalid key'] = 'Невірний ключ';
$lang['The passwords do not match'] = 'Паролі не співпадають';
$lang['Your password has been reset'] = 'Ваш пароль був оновлений';
$lang['Return to home page'] = 'Повернутися на домашню сторінку';
$lang['Please enter your username or email address.'] = 'Будь ласка введіть ваше ім\'я користувача або адресу електронної пошти.';
$lang['You will receive a link to create a new password via email.'] = 'Ви отримаєте посилання, щоб створити новий пароль по електронній пошті.';
$lang['Username or email'] = 'Ім\'я користувача або адреса електронної пошти';
$lang['Change my password'] = 'Змінити мій пароль';
$lang['Enter your new password below.'] = 'Введіть ваш новий пароль нижче.';
$lang['Reset Password'] = 'Оновити пароль';
$lang['EXIF Metadata'] = 'EXIF метадані';
$lang['IPTC Metadata'] = 'IPTC метадані';

?>